@@ -7,7 +7,7 @@ use Exporter 'import';
 use ExtUtils::MakeMaker;
 use XS::Install::Payload;
 
-our $VERSION = '1.0.4';
+our $VERSION = '1.0.5';
 my $THIS_MODULE = 'XS::Install';
 
 our @EXPORT_OK = qw/write_makefile makemaker_args/;
@@ -500,9 +500,9 @@ sub process_test {
         '$(TEST_XS_FILES) :: $(FIRST_MAKEFILE) '.join(' ', @xsi_files).'; $(TOUCH) $(TEST_XS_FILES)',
         "TEST_INST_DYNAMIC = $dlpath",
         'TEST_LDFROM = $(TEST_OBJECT) '.($shared_libs_linking||''),
-        '$(TEST_INST_DYNAMIC) : $(TEST_OBJECT)'."\n".
+        '$(TEST_INST_DYNAMIC) : $(TEST_OBJECT) $(INST_DYNAMIC)'."\n".
             "\t".'$(RM_F) $@'."\n".
-            "\t".'$(LD) $(LDDLFLAGS) $(TEST_LDFROM) $(OTHERLDFLAGS) -o $@ $(INST_DYNAMIC_FIX)'."\n".
+            "\t".'$(LD) $(LDDLFLAGS) $(TEST_LDFROM) $(INST_DYNAMIC) $(OTHERLDFLAGS) -o $@ $(INST_DYNAMIC_FIX)'."\n".
             "\t".'$(CHMOD) $(PERM_RWX) $@',
         'subdirs-test_dynamic :: $(TEST_INST_DYNAMIC)',
         'ctest :: subdirs-test_dynamic',
